spacepy.seapy.readepochs — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »

# spacepy.seapy.readepochs

`spacepy.seapy.` `readepochs`(fname, iso=False, isofmt='%Y-%m-%dT%H:%M:%S')

  Read epochs from text file assuming YYYY MM DD hh mm ss format

  Parameters: | Filename (include path) :
  Returns: | epochs (type=list) :
  Other Parameters:
  | iso (default = False), read in ISO date format : isofmt (default is YYYY-mm-ddTHH:MM:SS, code is %Y-%m-%dT%H:%M:%S) :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »